@@ -1,5 +1,4 @@
 """ torchsummary.py """
-from typing import Any, Dict, Generator, List, Optional, Sequence, Union
 
 import torch
 import torch.nn as nn
@@ -7,61 +6,45 @@ from torch.utils.hooks import RemovableHandle
 
 from .formatting import FormattingOptions, Verbosity
 from .layer_info import LayerInfo
-from .model_statistics import CORRECTED_INPUT_SIZE_TYPE, ModelStatistics
+from .model_statistics import ModelStatistics
 
 # Some modules do the computation themselves using parameters
 # or the parameters of children. Treat these as layers.
-LAYER_MODULES = (torch.nn.MultiheadAttention,)  # type: ignore
-INPUT_SIZE_TYPE = Sequence[Union[int, Sequence[Any], torch.Size]]
+LAYER_MODULES = (torch.nn.MultiheadAttention,)
 
-
-def summary(
-    model: nn.Module,
-    input_data: Union[torch.Tensor, torch.Size, Sequence[torch.Tensor], INPUT_SIZE_TYPE],
-    *args: Any,
-    batch_dim: int = 0,
-    branching: bool = True,
-    col_names: Sequence[str] = ("output_size", "num_params"),
-    col_width: int = 25,
-    depth: int = 3,
-    device: Optional[torch.device] = None,
-    dtypes: Optional[List[torch.dtype]] = None,
-    verbose: int = 1,
-    **kwargs: Any,
-) -> ModelStatistics:
+def summary(model, input_data, *args, batch_dim = 0, branching = True, col_names = ("output_size", "num_params"), col_width = 25, depth = 3, device = None, dtypes = None, verbose = 1, **kwargs):
     """
     Summarize the given PyTorch model. Summarized information includes:
-        1) output shape,
-        2) kernel shape,
-        3) number of the parameters
+        1) output shape, 2) kernel shape, 3) number of the parameters
         4) operations (Mult-Adds)
-    Args:
-        model (Module): Model to summarize
+        
+    Arguments:
+        model (nn.Module): PyTorch model to summarize
         input_data (Sequence of Sizes or Tensors):
             Example input tensor of the model (dtypes inferred from model input).
             - OR -
-            Shape of input data as a List/Tuple/torch.Size (dtypes must match model input,
-            default is FloatTensors).
+            Shape of input data as a List/Tuple/torch.Size (dtypes must match model input, default is FloatTensors).
+        batch_dim (int): batch_dimension of input data
         branching (bool): Whether to use the branching layout for the printed output.
+        col_names (Sequence[str]): specify which columns to show in the output.
+            Currently supported:
+            ('output_size', 'num_params', 'kernel_size', 'mult_adds')
+        col_width (int): width of each column
         depth (int): number of nested layers to traverse (e.g. Sequentials)
+        device (torch.Device): Uses this torch device for model and input_data.
+            Defaults to torch.cuda.is_available().
+        dtypes (List[torch.dtype]): for multiple inputs, specify the size of both inputs, and
+            also specify the types of each parameter here.
         verbose (int):
             0 (quiet): No output
             1 (default): Print model summary
             2 (verbose): Show weight and bias layers in full detail
-        col_names (List): specify which columns to show in the output. Currently supported:
-            ['output_size', 'num_params', 'kernel_size', 'mult_adds']
-        col_width (int): width of each column
-        dtypes (List or None): for multiple inputs or args, must specify the size of both inputs.
-            You must also specify the types of each parameter here.
-        batch_dim (int): batch_dimension of input data
-        device (torch.Device): If specified, uses this torch device for the model and model's input.
-            Else defaults to torch.cuda.is_available().
         args, kwargs: Other arguments used in `model.forward` function.
     """
     assert verbose in (0, 1, 2)
-    summary_list: List[LayerInfo] = []
-    hooks: List[RemovableHandle] = []
-    idx: Dict[int, int] = {}
+    summary_list = []
+    hooks = []
+    idx = {}
     apply_hooks(model, model, depth, summary_list, hooks, idx, batch_dim)
 
     if device is None:
@@ -83,8 +66,7 @@ def summary(
             x = get_input_tensor(input_size, batch_dim, dtypes, device)
 
     else:
-        raise TypeError(
-            "Input type is not recognized. Please ensure input_data is valid.\n"
+        raise TypeError("Input type is not recognized. Please ensure input_data is valid.\n"
             "For multiple inputs to the network, ensure input_data passed in is "
             "a sequence of tensors or a list of tuple sizes. If you are having trouble here, "
             "please submit a GitHub issue."
@@ -97,7 +79,7 @@ def summary(
         with torch.no_grad():
             _ = model.to(device)(*x, *args, **kwargs)
     except Exception:
-        print(f"Failed to run torchsummary, printing sizes of executed layers: {summary_list}")
+        print("Failed to run torchsummary, printing sizes of executed layers: {}".format(summary_list))
         raise
     finally:
         for hook in hooks:
@@ -111,12 +93,7 @@ def summary(
     return results
 
 
-def get_input_tensor(
-    input_size: CORRECTED_INPUT_SIZE_TYPE,
-    batch_dim: int,
-    dtypes: List[torch.dtype],
-    device: torch.device,
-) -> List[torch.Tensor]:
+def get_input_tensor(input_size, batch_dim, dtypes, device):
     """ Get input_tensor with batch size 2 for use in model.forward() """
     x = []
     for size, dtype in zip(input_size, dtypes):
@@ -132,11 +109,11 @@ def get_input_tensor(
     return x
 
 
-def get_correct_input_sizes(input_size: INPUT_SIZE_TYPE) -> CORRECTED_INPUT_SIZE_TYPE:
+def get_correct_input_sizes(input_size):
     """ Convert input_size to the correct form, which is a list of tuples.
     Also handles multiple inputs to the network. """
 
-    def flatten(nested_array: INPUT_SIZE_TYPE) -> Generator:
+    def flatten(nested_array):
         """ Flattens a nested array. """
         for item in nested_array:
             if isinstance(item, (list, tuple)):
@@ -156,19 +133,10 @@ def get_correct_input_sizes(input_size: INPUT_SIZE_TYPE) -> CORRECTED_INPUT_SIZE
     return [input_size]
 
 
-def apply_hooks(
-    module: nn.Module,
-    orig_model: nn.Module,
-    depth: int,
-    summary_list: List[LayerInfo],
-    hooks: List[RemovableHandle],
-    idx: Dict[int, int],
-    batch_dim: int,
-    curr_depth: int = 0,
-) -> None:
+def apply_hooks(module, orig_model, depth, summary_list, hooks, idx, batch_dim, curr_depth = 0):
     """ Recursively adds hooks to all layers of the model. """
 
-    def hook(module: nn.Module, inputs: Any, outputs: Any) -> None:
+    def hook(module, inputs, outputs):
         """ Create a LayerInfo object to aggregate information about that layer. """
         del inputs
         idx[curr_depth] = idx.get(curr_depth, 0) + 1
@@ -185,6 +153,5 @@ def apply_hooks(
 
     if curr_depth <= depth:
         for child in module.children():
-            apply_hooks(
-                child, orig_model, depth, summary_list, hooks, idx, batch_dim, curr_depth + 1
+            apply_hooks(child, orig_model, depth, summary_list, hooks, idx, batch_dim, curr_depth + 1
             )
